@@ -1,19 +1,26 @@
 """
     gpytranslate - A Python3 library for translating text using Google Translate API.
-    Copyright (C) 2020-2021  Davide Galilei
+    MIT License
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
+    Copyright (c) 2023 Davide Galilei
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+    Permission is hereby granted, free of charge, to any person obtaining a copy
+    of this software and associated documentation files (the "Software"), to deal
+    in the Software without restriction, including without limitation the rights
+    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+    copies of the Software, and to permit persons to whom the Software is
+    furnished to do so, subject to the following conditions:
 
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <https://www.gnu.org/licenses/>.
+    The above copyright notice and this permission notice shall be included in all
+    copies or substantial portions of the Software.
+
+    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+    SOFTWARE.
 """
 
 from collections.abc import Mapping
@@ -21,24 +28,30 @@ from typing import Union, Dict, List, Any, BinaryIO
 
 import httpx
 
-from ..types import TranslatedObject, BaseTranslator, BASE_HEADERS
+from ..exceptions import TranslationError
+from ..types import (
+    TranslatedObject,
+    BaseTranslator,
+    get_base_headers,
+    DEFAULT_TRANSLATION_ENDPOINT,
+    DEFAULT_TTS_ENDPOINT,
+)
 
 
 class SyncTranslator(BaseTranslator):
     def __init__(
         self,
         proxies: Dict[str, str] = None,
-        url: str = "https://translate.googleapis.com/translate_a/single",
-        tts_url: str = "https://translate.google.com/translate_tts",
-        headers: dict = ...,
+        url: str = DEFAULT_TRANSLATION_ENDPOINT,
+        tts_url: str = DEFAULT_TTS_ENDPOINT,
+        headers: Union[dict, callable] = ...,
         **options
     ):
         self.url = url
         self.tts_url = tts_url
         self.proxies = proxies
         self.options = options
-        self.headers = BASE_HEADERS if headers is Ellipsis else headers
-        self.client: httpx.Client = httpx.Client(proxies=proxies, **options)
+        self.headers = get_base_headers if headers is Ellipsis else headers
 
     def translate(
         self,
@@ -58,7 +71,7 @@ class SyncTranslator(BaseTranslator):
             text: str = Text to translate.
 
 
-            sourcelang: str = "text" original language, pass "auto" for auto detection (default: "auto").
+            sourcelang: str = "text" original language, pass "auto" for auto-detection (default: "auto").
 
 
             targetlang: str = target language for translating "text" (default: "en").
@@ -68,7 +81,7 @@ class SyncTranslator(BaseTranslator):
                 (Will return the raw API json if "client" is not "gtx")
 
 
-            dt: str = Specifies what to return in the API reply (default: "t").
+            dt: str = Specifies what to return to the API reply (default: "t").
                 (Will return the raw API json if "dt" is not "t".
                 t - Translation of source text;
                 at - Alternate translations;
@@ -103,38 +116,40 @@ class SyncTranslator(BaseTranslator):
             }.items()
             if v is not None
         }
-        with self.client as c:
-            raw: Union[Mapping, List] = (
-                (
+        try:
+            with httpx.Client(proxies=self.proxies, **self.options) as c:
+                raw: Union[Mapping, List] = (
                     c.post(
                         self.url,
                         params={**params, "q": text},
-                        headers=self.headers,
+                        headers=self.get_headers(),
+                    ).json()
+                    if isinstance(text, str)
+                    else (
+                        {
+                            k: c.post(
+                                self.url,
+                                params={**params, "q": v},
+                                headers=self.get_headers(),
+                            ).json()
+                            for k, v in text.items()
+                        }
+                        if isinstance(text, Mapping)
+                        else [
+                            c.post(
+                                self.url,
+                                params={**params, "q": elem},
+                                headers=self.get_headers(),
+                            ).json()
+                            for elem in text
+                        ]
                     )
-                ).json()
-                if isinstance(text, str)
-                else (
-                    {
-                        k: c.post(
-                            self.url,
-                            params={**params, "q": v},
-                            headers=self.headers,
-                        ).json()
-                        for k, v in text.items()
-                    }
-                    if isinstance(text, Mapping)
-                    else [
-                        c.post(
-                            self.url,
-                            params={**params, "q": elem},
-                            headers=self.headers,
-                        ).json()
-                        for elem in text
-                    ]
                 )
-            )
+                c.close()
 
-        return self.check(raw=raw, client=client, dt=dt, text=text)
+            return self.check(raw=raw, client=client, dt=dt, text=text)
+        except Exception as e:
+            raise TranslationError(e) from None
 
     def detect(self, text: Union[str, list, dict]):
         if isinstance(text, str):
@@ -167,15 +182,18 @@ class SyncTranslator(BaseTranslator):
             textlen=textlen,
             extra=extra,
         )
-        with httpx.stream(
-            "GET",
-            url=self.tts_url,
-            params=params,
-            headers=self.headers,
-        ) as response:
-            response: httpx.Response
-            for chunk in response.iter_bytes(chunk_size=chunk_size):
-                file.write(chunk)
-        return file
+        try:
+            with httpx.stream(
+                "GET",
+                url=self.tts_url,
+                params=params,
+                headers=self.get_headers(),
+            ) as response:
+                response: httpx.Response
+                for chunk in response.iter_bytes(chunk_size=chunk_size):
+                    file.write(chunk)
+            return file
+        except Exception as e:
+            raise TranslationError(e) from None
 
     __call__ = translate
